(weekly?) Typos (fwd)

Francois Gouget fgouget at free.fr
Sun Nov 18 12:13:20 CST 2001


Sent on the 15th, got lost without a trace!


---------- Forwarded message ----------
Date: Thu, 15 Nov 2001 17:22:14 -0800 (PST)
From: Francois Gouget <fgouget at free.fr>
To: wine-patches at winehq.com
Subject: (weekly?) Typos



Changelog:

 * dlls/dinput/joystick/linux.c,
   dlls/shlwapi/url.c,
   include/msvcrt/process.h

   A few typos.


--
Francois Gouget         fgouget at free.fr        http://fgouget.free.fr/
                           La terre est une bêta...
-------------- next part --------------
Index: dlls/dinput/joystick/linux.c
===================================================================
RCS file: /home/wine/wine/dlls/dinput/joystick/linux.c,v
retrieving revision 1.5
diff -u -r1.5 linux.c
--- dlls/dinput/joystick/linux.c	2001/01/28 23:14:25	1.5
+++ dlls/dinput/joystick/linux.c	2001/11/15 23:14:24
@@ -265,7 +265,7 @@
 		This->js.lZ = map_axis(jse.value);
 		break;
 	    default:
-		FIXME("more then 3 axes (%d) not handled!\n",jse.number);
+		FIXME("more than 3 axes (%d) not handled!\n",jse.number);
 		break;
 	    }
 	}
Index: include/msvcrt/process.h
===================================================================
RCS file: /home/wine/wine/include/msvcrt/process.h,v
retrieving revision 1.3
diff -u -r1.3 process.h
--- include/msvcrt/process.h	2001/10/22 18:59:23	1.3
+++ include/msvcrt/process.h	2001/11/15 23:14:38
@@ -56,7 +56,7 @@
 int         _spawnlpe(int,const char*,const char*,...);
 int         _spawnv(int,const char*,const char* const *);
 int         _spawnve(int,const char*,const char* const *,const char* const *);
-int         _spawnvp(int,const char* ,const char* const *);
+int         _spawnvp(int,const char*,const char* const *);
 int         _spawnvpe(int,const char*,const char* const *,const char* const *);
 
 void        MSVCRT(_c_exit)(void);


More information about the wine-patches mailing list
Index: dlls/shlwapi/url.c
===================================================================
RCS file: /home/wine/wine/dlls/shlwapi/url.c,v
retrieving revision 1.10
diff -u -r1.10 url.c
--- dlls/shlwapi/url.c	2001/11/13 21:28:21	1.10
+++ dlls/shlwapi/url.c	2001/11/15 03:50:53
@@ -356,7 +356,7 @@
 	EscapeFlags &= ~URL_ESCAPE_UNSAFE;
 	hr = UrlEscapeW(lpszUrlCpy, pszCanonicalized, pcchCanonicalized,
 			EscapeFlags);
-    } else { /* No escapping needed, just copy the string */
+    } else { /* No escaping needed, just copy the string */
         nLen = lstrlenW(lpszUrlCpy);
 	if(nLen < *pcchCanonicalized)
 	    memcpy(pszCanonicalized, lpszUrlCpy, (nLen + 1)*sizeof(WCHAR));
@@ -712,7 +712,7 @@
 {
     LPCSTR src;
     DWORD needed = 0, ret;
-    BOOL stop_escapping = FALSE;
+    BOOL stop_escaping = FALSE;
     char next[3], *dst = pszEscaped;
     char hex[] = "0123456789ABCDEF";
     INT len;
@@ -741,9 +741,9 @@
         if(!(dwFlags & URL_ESCAPE_SEGMENT_ONLY) &&
 	   (dwFlags & URL_DONT_ESCAPE_EXTRA_INFO) &&
 	   (*src == '#' || *src == '?'))
-	    stop_escapping = TRUE;
+	    stop_escaping = TRUE;
 
-	if(URL_NeedEscapeA(*src, dwFlags) && stop_escapping == FALSE) {
+	if(URL_NeedEscapeA(*src, dwFlags) && stop_escaping == FALSE) {
 	    /* TRACE("escaping %c\n", *src); */
 	    next[0] = '%';
 	    next[1] = hex[(*src >> 4) & 0xf];
@@ -786,7 +786,7 @@
 {
     LPCWSTR src;
     DWORD needed = 0, ret;
-    BOOL stop_escapping = FALSE;
+    BOOL stop_escaping = FALSE;
     WCHAR next[5], *dst = pszEscaped;
     CHAR hex[] = "0123456789ABCDEF";
     INT len;
@@ -815,14 +815,14 @@
 	/*
 	 * if(!(dwFlags & URL_ESCAPE_SPACES_ONLY) &&
 	 *   (*src == L'#' || *src == L'?'))
-	 *    stop_escapping = TRUE;
+	 *    stop_escaping = TRUE;
 	 */
         if(!(dwFlags & URL_ESCAPE_SEGMENT_ONLY) &&
 	   (dwFlags & URL_DONT_ESCAPE_EXTRA_INFO) &&
 	   (*src == L'#' || *src == L'?'))
-	    stop_escapping = TRUE;
+	    stop_escaping = TRUE;
 
-	if(URL_NeedEscapeW(*src, dwFlags) && stop_escapping == FALSE) {
+	if(URL_NeedEscapeW(*src, dwFlags) && stop_escaping == FALSE) {
 	    /* TRACE("escaping %c\n", *src); */
 	    next[0] = L'%';
 	    /*
@@ -891,7 +891,7 @@
     LPCSTR src;
     HRESULT ret;
     DWORD needed;
-    BOOL stop_unescapping = FALSE;
+    BOOL stop_unescaping = FALSE;
 
     TRACE("(%s, %p, %p, 0x%08lx)\n", debugstr_a(pszUrl), pszUnescaped,
 	  pcchUnescaped, dwFlags);
@@ -904,10 +904,10 @@
     for(src = pszUrl, needed = 0; *src; src++, needed++) {
         if(dwFlags & URL_DONT_UNESCAPE_EXTRA_INFO &&
 	   (*src == '#' || *src == '?')) {
-	    stop_unescapping = TRUE;
+	    stop_unescaping = TRUE;
 	    next = *src;
 	} else if(*src == '%' && isxdigit(*(src + 1)) && isxdigit(*(src + 2))
-		  && stop_unescapping == FALSE) {
+		  && stop_unescaping == FALSE) {
 	    INT ih;
 	    char buf[3];
 	    memcpy(buf, src + 1, 2);
@@ -955,7 +955,7 @@
     LPCWSTR src;
     HRESULT ret;
     DWORD needed;
-    BOOL stop_unescapping = FALSE;
+    BOOL stop_unescaping = FALSE;
 
     TRACE("(%s, %p, %p, 0x%08lx)\n", debugstr_w(pszUrl), pszUnescaped,
 	  pcchUnescaped, dwFlags);
@@ -968,10 +968,10 @@
     for(src = pszUrl, needed = 0; *src; src++, needed++) {
         if(dwFlags & URL_DONT_UNESCAPE_EXTRA_INFO &&
 	   (*src == L'#' || *src == L'?')) {
-	    stop_unescapping = TRUE;
+	    stop_unescaping = TRUE;
 	    next = *src;
 	} else if(*src == L'%' && isxdigitW(*(src + 1)) && isxdigitW(*(src + 2))
-		  && stop_unescapping == FALSE) {
+		  && stop_unescaping == FALSE) {
 	    INT ih;
 	    WCHAR buf[3];
 	    memcpy(buf, src + 1, 2*sizeof(WCHAR));